Module: PhlexKit
- Defined in:
- lib/phlex_kit/icons/remix.rb,
lib/phlex_kit.rb,
lib/phlex_kit/icons.rb,
lib/phlex_kit/engine.rb,
lib/phlex_kit/version.rb,
lib/phlex_kit/icons/lucide.rb,
lib/phlex_kit/icons/tabler.rb,
lib/phlex_kit/configuration.rb,
lib/phlex_kit/base_component.rb,
lib/phlex_kit/icons/phosphor.rb,
app/components/phlex_kit/kbd/kbd.rb,
app/components/phlex_kit/card/card.rb,
app/components/phlex_kit/form/form.rb,
app/components/phlex_kit/icon/icon.rb,
app/components/phlex_kit/item/item.rb,
app/components/phlex_kit/link/link.rb,
app/components/phlex_kit/tabs/tabs.rb,
lib/phlex_kit/propshaft_skip_source.rb,
app/components/phlex_kit/alert/alert.rb,
app/components/phlex_kit/badge/badge.rb,
app/components/phlex_kit/chart/chart.rb,
app/components/phlex_kit/empty/empty.rb,
app/components/phlex_kit/field/field.rb,
app/components/phlex_kit/input/input.rb,
app/components/phlex_kit/label/label.rb,
app/components/phlex_kit/sheet/sheet.rb,
app/components/phlex_kit/table/table.rb,
app/components/phlex_kit/toast/toast.rb,
app/components/phlex_kit/avatar/avatar.rb,
app/components/phlex_kit/bubble/bubble.rb,
app/components/phlex_kit/button/button.rb,
app/components/phlex_kit/dialog/dialog.rb,
app/components/phlex_kit/drawer/drawer.rb,
app/components/phlex_kit/kbd/kbd_group.rb,
app/components/phlex_kit/marker/marker.rb,
app/components/phlex_kit/select/select.rb,
app/components/phlex_kit/slider/slider.rb,
app/components/phlex_kit/switch/switch.rb,
app/components/phlex_kit/toggle/toggle.rb,
app/components/phlex_kit/tabs/tabs_list.rb,
app/components/phlex_kit/card/card_title.rb,
app/components/phlex_kit/command/command.rb,
app/components/phlex_kit/field/field_set.rb,
app/components/phlex_kit/item/item_group.rb,
app/components/phlex_kit/item/item_media.rb,
app/components/phlex_kit/item/item_title.rb,
app/components/phlex_kit/menubar/menubar.rb,
app/components/phlex_kit/message/message.rb,
app/components/phlex_kit/popover/popover.rb,
app/components/phlex_kit/sidebar/sidebar.rb,
app/components/phlex_kit/spinner/spinner.rb,
app/components/phlex_kit/table/table_row.rb,
app/components/phlex_kit/tooltip/tooltip.rb,
app/components/phlex_kit/typography/text.rb,
app/components/phlex_kit/card/card_action.rb,
app/components/phlex_kit/card/card_footer.rb,
app/components/phlex_kit/card/card_header.rb,
app/components/phlex_kit/item/item_footer.rb,
app/components/phlex_kit/item/item_header.rb,
app/components/phlex_kit/table/table_body.rb,
app/components/phlex_kit/table/table_cell.rb,
app/components/phlex_kit/table/table_head.rb,
app/components/phlex_kit/toast/toast_icon.rb,
app/components/phlex_kit/toast/toast_item.rb,
app/components/phlex_kit/alert/alert_title.rb,
app/components/phlex_kit/calendar/calendar.rb,
app/components/phlex_kit/card/card_content.rb,
app/components/phlex_kit/carousel/carousel.rb,
app/components/phlex_kit/checkbox/checkbox.rb,
app/components/phlex_kit/combobox/combobox.rb,
app/components/phlex_kit/empty/empty_media.rb,
app/components/phlex_kit/empty/empty_title.rb,
app/components/phlex_kit/field/field_error.rb,
app/components/phlex_kit/field/field_group.rb,
app/components/phlex_kit/field/field_label.rb,
app/components/phlex_kit/field/field_title.rb,
app/components/phlex_kit/item/item_actions.rb,
app/components/phlex_kit/item/item_content.rb,
app/components/phlex_kit/progress/progress.rb,
app/components/phlex_kit/sheet/sheet_close.rb,
app/components/phlex_kit/sheet/sheet_title.rb,
app/components/phlex_kit/skeleton/skeleton.rb,
app/components/phlex_kit/tabs/tabs_content.rb,
app/components/phlex_kit/tabs/tabs_trigger.rb,
app/components/phlex_kit/textarea/textarea.rb,
app/components/phlex_kit/toast/toast_close.rb,
app/components/phlex_kit/toast/toast_title.rb,
app/components/phlex_kit/alert/alert_action.rb,
app/components/phlex_kit/empty/empty_header.rb,
app/components/phlex_kit/field/field_legend.rb,
app/components/phlex_kit/marker/marker_icon.rb,
app/components/phlex_kit/select/select_item.rb,
app/components/phlex_kit/sheet/sheet_footer.rb,
app/components/phlex_kit/sheet/sheet_header.rb,
app/components/phlex_kit/sheet/sheet_middle.rb,
app/components/phlex_kit/table/table_footer.rb,
app/components/phlex_kit/table/table_header.rb,
app/components/phlex_kit/toast/toast_action.rb,
app/components/phlex_kit/toast/toast_cancel.rb,
app/components/phlex_kit/toast/toast_region.rb,
app/components/phlex_kit/typography/heading.rb,
app/components/phlex_kit/accordion/accordion.rb,
app/components/phlex_kit/avatar/avatar_badge.rb,
app/components/phlex_kit/avatar/avatar_group.rb,
app/components/phlex_kit/avatar/avatar_image.rb,
app/components/phlex_kit/bubble/bubble_group.rb,
app/components/phlex_kit/clipboard/clipboard.rb,
app/components/phlex_kit/codeblock/codeblock.rb,
app/components/phlex_kit/dialog/dialog_close.rb,
app/components/phlex_kit/dialog/dialog_title.rb,
app/components/phlex_kit/drawer/drawer_close.rb,
app/components/phlex_kit/drawer/drawer_title.rb,
app/components/phlex_kit/empty/empty_content.rb,
app/components/phlex_kit/field/field_content.rb,
app/components/phlex_kit/input_otp/input_otp.rb,
app/components/phlex_kit/item/item_separator.rb,
app/components/phlex_kit/menubar/menubar_sub.rb,
app/components/phlex_kit/select/select_group.rb,
app/components/phlex_kit/select/select_input.rb,
app/components/phlex_kit/select/select_label.rb,
app/components/phlex_kit/select/select_value.rb,
app/components/phlex_kit/separator/separator.rb,
app/components/phlex_kit/sheet/sheet_content.rb,
app/components/phlex_kit/sheet/sheet_trigger.rb,
app/components/phlex_kit/table/table_caption.rb,
app/components/phlex_kit/command/command_item.rb,
app/components/phlex_kit/command/command_list.rb,
app/components/phlex_kit/dialog/dialog_footer.rb,
app/components/phlex_kit/dialog/dialog_header.rb,
app/components/phlex_kit/dialog/dialog_middle.rb,
app/components/phlex_kit/drawer/drawer_footer.rb,
app/components/phlex_kit/drawer/drawer_header.rb,
app/components/phlex_kit/menubar/menubar_item.rb,
app/components/phlex_kit/menubar/menubar_menu.rb,
app/components/phlex_kit/sidebar/sidebar_menu.rb,
app/components/phlex_kit/sidebar/sidebar_rail.rb,
app/components/phlex_kit/attachment/attachment.rb,
app/components/phlex_kit/breadcrumb/breadcrumb.rb,
app/components/phlex_kit/bubble/bubble_content.rb,
app/components/phlex_kit/card/card_description.rb,
app/components/phlex_kit/command/command_empty.rb,
app/components/phlex_kit/command/command_group.rb,
app/components/phlex_kit/command/command_input.rb,
app/components/phlex_kit/data_table/data_table.rb,
app/components/phlex_kit/dialog/dialog_content.rb,
app/components/phlex_kit/dialog/dialog_trigger.rb,
app/components/phlex_kit/drawer/drawer_content.rb,
app/components/phlex_kit/drawer/drawer_trigger.rb,
app/components/phlex_kit/field/field_separator.rb,
app/components/phlex_kit/form_field/form_field.rb,
app/components/phlex_kit/hover_card/hover_card.rb,
app/components/phlex_kit/item/item_description.rb,
app/components/phlex_kit/marker/marker_content.rb,
app/components/phlex_kit/menubar/menubar_group.rb,
app/components/phlex_kit/menubar/menubar_label.rb,
app/components/phlex_kit/message/message_group.rb,
app/components/phlex_kit/pagination/pagination.rb,
app/components/phlex_kit/popover/popover_title.rb,
app/components/phlex_kit/select/select_content.rb,
app/components/phlex_kit/select/select_trigger.rb,
app/components/phlex_kit/sidebar/sidebar_group.rb,
app/components/phlex_kit/sidebar/sidebar_input.rb,
app/components/phlex_kit/sidebar/sidebar_inset.rb,
app/components/phlex_kit/typography/blockquote.rb,
app/components/phlex_kit/avatar/avatar_fallback.rb,
app/components/phlex_kit/calendar/calendar_body.rb,
app/components/phlex_kit/calendar/calendar_days.rb,
app/components/phlex_kit/calendar/calendar_next.rb,
app/components/phlex_kit/calendar/calendar_prev.rb,
app/components/phlex_kit/carousel/carousel_item.rb,
app/components/phlex_kit/carousel/carousel_next.rb,
app/components/phlex_kit/combobox/combobox_item.rb,
app/components/phlex_kit/combobox/combobox_list.rb,
app/components/phlex_kit/command/command_dialog.rb,
app/components/phlex_kit/message/message_avatar.rb,
app/components/phlex_kit/message/message_footer.rb,
app/components/phlex_kit/message/message_header.rb,
app/components/phlex_kit/popover/popover_header.rb,
app/components/phlex_kit/sidebar/sidebar_footer.rb,
app/components/phlex_kit/sidebar/sidebar_header.rb,
app/components/phlex_kit/typography/inline_code.rb,
app/components/phlex_kit/typography/inline_link.rb,
app/components/phlex_kit/alert/alert_description.rb,
app/components/phlex_kit/bubble/bubble_reactions.rb,
app/components/phlex_kit/calendar/calendar_title.rb,
app/components/phlex_kit/collapsible/collapsible.rb,
app/components/phlex_kit/combobox/combobox_badge.rb,
app/components/phlex_kit/combobox/combobox_radio.rb,
app/components/phlex_kit/date_picker/date_picker.rb,
app/components/phlex_kit/empty/empty_description.rb,
app/components/phlex_kit/field/field_description.rb,
app/components/phlex_kit/input_group/input_group.rb,
app/components/phlex_kit/menubar/menubar_content.rb,
app/components/phlex_kit/menubar/menubar_trigger.rb,
app/components/phlex_kit/message/message_content.rb,
app/components/phlex_kit/popover/popover_content.rb,
app/components/phlex_kit/popover/popover_trigger.rb,
app/components/phlex_kit/radio_group/radio_group.rb,
app/components/phlex_kit/scroll_area/scroll_area.rb,
app/components/phlex_kit/select/select_separator.rb,
app/components/phlex_kit/sheet/sheet_description.rb,
app/components/phlex_kit/sidebar/sidebar_content.rb,
app/components/phlex_kit/sidebar/sidebar_trigger.rb,
app/components/phlex_kit/sidebar/sidebar_wrapper.rb,
app/components/phlex_kit/toast/toast_description.rb,
app/components/phlex_kit/tooltip/tooltip_content.rb,
app/components/phlex_kit/tooltip/tooltip_trigger.rb,
app/components/phlex_kit/accordion/accordion_icon.rb,
app/components/phlex_kit/accordion/accordion_item.rb,
app/components/phlex_kit/calendar/calendar_header.rb,
app/components/phlex_kit/command/command_shortcut.rb,
app/components/phlex_kit/input_otp/input_otp_slot.rb,
app/components/phlex_kit/menubar/menubar_shortcut.rb,
app/components/phlex_kit/sidebar/sidebar_menu_sub.rb,
app/components/phlex_kit/alert_dialog/alert_dialog.rb,
app/components/phlex_kit/aspect_ratio/aspect_ratio.rb,
app/components/phlex_kit/avatar/avatar_group_count.rb,
app/components/phlex_kit/button_group/button_group.rb,
app/components/phlex_kit/carousel/carousel_content.rb,
app/components/phlex_kit/combobox/combobox_popover.rb,
app/components/phlex_kit/combobox/combobox_trigger.rb,
app/components/phlex_kit/command/command_separator.rb,
app/components/phlex_kit/context_menu/context_menu.rb,
app/components/phlex_kit/dialog/dialog_description.rb,
app/components/phlex_kit/drawer/drawer_description.rb,
app/components/phlex_kit/input_otp/input_otp_group.rb,
app/components/phlex_kit/masked_input/masked_input.rb,
app/components/phlex_kit/menubar/menubar_separator.rb,
app/components/phlex_kit/radio_button/radio_button.rb,
app/components/phlex_kit/resizable/resizable_panel.rb,
app/components/phlex_kit/shortcut_key/shortcut_key.rb,
app/components/phlex_kit/sidebar/sidebar_menu_item.rb,
app/components/phlex_kit/sidebar/sidebar_separator.rb,
app/components/phlex_kit/theme_toggle/theme_toggle.rb,
app/components/phlex_kit/toggle_group/toggle_group.rb,
lib/generators/phlex_kit/install/install_generator.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_item.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_link.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_list.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_page.rb,
app/components/phlex_kit/calendar/calendar_weekdays.rb,
app/components/phlex_kit/carousel/carousel_previous.rb,
app/components/phlex_kit/clipboard/clipboard_source.rb,
app/components/phlex_kit/combobox/combobox_checkbox.rb,
app/components/phlex_kit/data_table/data_table_form.rb,
app/components/phlex_kit/form_field/form_field_hint.rb,
app/components/phlex_kit/menubar/menubar_radio_item.rb,
app/components/phlex_kit/pagination/pagination_item.rb,
app/components/phlex_kit/pagination/pagination_link.rb,
app/components/phlex_kit/pagination/pagination_next.rb,
app/components/phlex_kit/resizable/resizable_handle.rb,
app/components/phlex_kit/sidebar/sidebar_menu_badge.rb,
app/components/phlex_kit/accordion/accordion_content.rb,
app/components/phlex_kit/accordion/accordion_trigger.rb,
app/components/phlex_kit/attachment/attachment_group.rb,
app/components/phlex_kit/attachment/attachment_media.rb,
app/components/phlex_kit/attachment/attachment_title.rb,
app/components/phlex_kit/clipboard/clipboard_popover.rb,
app/components/phlex_kit/clipboard/clipboard_trigger.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu.rb,
app/components/phlex_kit/form_field/form_field_error.rb,
app/components/phlex_kit/form_field/form_field_label.rb,
app/components/phlex_kit/menubar/menubar_radio_group.rb,
app/components/phlex_kit/menubar/menubar_sub_content.rb,
app/components/phlex_kit/menubar/menubar_sub_trigger.rb,
app/components/phlex_kit/native_select/native_select.rb,
app/components/phlex_kit/popover/popover_description.rb,
app/components/phlex_kit/sidebar/sidebar_group_label.rb,
app/components/phlex_kit/sidebar/sidebar_menu_action.rb,
app/components/phlex_kit/sidebar/sidebar_menu_button.rb,
app/components/phlex_kit/attachment/attachment_action.rb,
app/components/phlex_kit/combobox/combobox_list_group.rb,
app/components/phlex_kit/data_table/data_table_search.rb,
app/components/phlex_kit/input_group/input_group_text.rb,
app/components/phlex_kit/sidebar/sidebar_group_action.rb,
app/components/phlex_kit/attachment/attachment_actions.rb,
app/components/phlex_kit/attachment/attachment_content.rb,
app/components/phlex_kit/attachment/attachment_trigger.rb,
app/components/phlex_kit/combobox/combobox_empty_state.rb,
app/components/phlex_kit/context_menu/context_menu_sub.rb,
app/components/phlex_kit/data_table/data_table_toolbar.rb,
app/components/phlex_kit/hover_card/hover_card_content.rb,
app/components/phlex_kit/hover_card/hover_card_trigger.rb,
app/components/phlex_kit/input_group/input_group_addon.rb,
app/components/phlex_kit/input_otp/input_otp_separator.rb,
app/components/phlex_kit/menubar/menubar_checkbox_item.rb,
app/components/phlex_kit/pagination/pagination_content.rb,
app/components/phlex_kit/sidebar/sidebar_group_content.rb,
app/components/phlex_kit/sidebar/sidebar_menu_skeleton.rb,
app/components/phlex_kit/sidebar/sidebar_menu_sub_item.rb,
lib/generators/phlex_kit/component/component_generator.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_ellipsis.rb,
app/components/phlex_kit/button_group/button_group_text.rb,
app/components/phlex_kit/combobox/combobox_clear_button.rb,
app/components/phlex_kit/combobox/combobox_search_input.rb,
app/components/phlex_kit/command/command_dialog_content.rb,
app/components/phlex_kit/command/command_dialog_trigger.rb,
app/components/phlex_kit/context_menu/context_menu_item.rb,
app/components/phlex_kit/input_group/input_group_button.rb,
app/components/phlex_kit/pagination/pagination_ellipsis.rb,
app/components/phlex_kit/pagination/pagination_previous.rb,
app/components/phlex_kit/toggle_group/toggle_group_item.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_media.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_title.rb,
app/components/phlex_kit/breadcrumb/breadcrumb_separator.rb,
app/components/phlex_kit/collapsible/collapsible_content.rb,
app/components/phlex_kit/collapsible/collapsible_trigger.rb,
app/components/phlex_kit/combobox/combobox_badge_trigger.rb,
app/components/phlex_kit/combobox/combobox_input_trigger.rb,
app/components/phlex_kit/context_menu/context_menu_group.rb,
app/components/phlex_kit/context_menu/context_menu_label.rb,
app/components/phlex_kit/data_table/data_table_sort_head.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_sub.rb,
app/components/phlex_kit/navigation_menu/navigation_menu.rb,
app/components/phlex_kit/resizable/resizable_panel_group.rb,
app/components/phlex_kit/sidebar/sidebar_menu_sub_button.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_action.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_cancel.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_footer.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_header.rb,
app/components/phlex_kit/combobox/combobox_item_indicator.rb,
app/components/phlex_kit/data_table/data_table_pagination.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_item.rb,
app/components/phlex_kit/native_select/native_select_icon.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_content.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_trigger.rb,
app/components/phlex_kit/attachment/attachment_description.rb,
app/components/phlex_kit/context_menu/context_menu_content.rb,
app/components/phlex_kit/context_menu/context_menu_trigger.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_group.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_label.rb,
app/components/phlex_kit/message_scroller/message_scroller.rb,
app/components/phlex_kit/native_select/native_select_group.rb,
app/components/phlex_kit/context_menu/context_menu_shortcut.rb,
app/components/phlex_kit/data_table/data_table_bulk_actions.rb,
app/components/phlex_kit/data_table/data_table_pagy_adapter.rb,
app/components/phlex_kit/data_table/data_table_row_checkbox.rb,
app/components/phlex_kit/native_select/native_select_option.rb,
app/components/phlex_kit/accordion/accordion_default_content.rb,
app/components/phlex_kit/accordion/accordion_default_trigger.rb,
app/components/phlex_kit/button_group/button_group_separator.rb,
app/components/phlex_kit/context_menu/context_menu_separator.rb,
app/components/phlex_kit/data_table/data_table_column_toggle.rb,
app/components/phlex_kit/data_table/data_table_expand_toggle.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_content.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_trigger.rb,
app/components/phlex_kit/context_menu/context_menu_radio_item.rb,
app/components/phlex_kit/data_table/data_table_manual_adapter.rb,
app/components/phlex_kit/data_table/data_table_pagination_bar.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_shortcut.rb,
app/components/phlex_kit/navigation_menu/navigation_menu_item.rb,
app/components/phlex_kit/navigation_menu/navigation_menu_link.rb,
app/components/phlex_kit/navigation_menu/navigation_menu_list.rb,
app/components/phlex_kit/alert_dialog/alert_dialog_description.rb,
app/components/phlex_kit/combobox/combobox_toggle_all_checkbox.rb,
app/components/phlex_kit/context_menu/context_menu_radio_group.rb,
app/components/phlex_kit/context_menu/context_menu_sub_content.rb,
app/components/phlex_kit/context_menu/context_menu_sub_trigger.rb,
app/components/phlex_kit/data_table/data_table_per_page_select.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_separator.rb,
app/components/phlex_kit/data_table/data_table_kaminari_adapter.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_radio_item.rb,
app/components/phlex_kit/context_menu/context_menu_checkbox_item.rb,
app/components/phlex_kit/data_table/data_table_selection_summary.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_radio_group.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_sub_content.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_sub_trigger.rb,
app/components/phlex_kit/navigation_menu/navigation_menu_content.rb,
app/components/phlex_kit/navigation_menu/navigation_menu_trigger.rb,
app/components/phlex_kit/data_table/data_table_select_all_checkbox.rb,
app/components/phlex_kit/dropdown_menu/dropdown_menu_checkbox_item.rb
Overview
The gem puts app/components on Propshaft's asset load path so component CSS can sit beside its .rb (see PhlexKit::Engine). Propshaft indexes EVERY non-dotfile in a path directory — it only skips dotfiles, with no extension allowlist — so it would otherwise digest our Ruby source into public/assets/ and serve it as a static file. Teach the load path to skip source files as well as dotfiles.
This hooks a PRIVATE Propshaft method; test/assets/asset_load_path_test.rb (and the same guard in a host app) fails loudly if a Propshaft upgrade breaks it.
Defined Under Namespace
Modules: Generators, Icons, PropshaftSkipSourceFiles, Toast Classes: Accordion, AccordionContent, AccordionDefaultContent, AccordionDefaultTrigger, AccordionIcon, AccordionItem, AccordionTrigger, Alert, AlertAction, AlertDescription, AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogMedia, AlertDialogTitle, AlertDialogTrigger, AlertTitle, AspectRatio, Attachment, AttachmentAction, AttachmentActions, AttachmentContent, AttachmentDescription, AttachmentGroup, AttachmentMedia, AttachmentTitle, AttachmentTrigger, Avatar, AvatarBadge, AvatarFallback, AvatarGroup, AvatarGroupCount, AvatarImage, Badge, BaseComponent, Blockquote, Breadcrumb, BreadcrumbEllipsis, BreadcrumbItem, BreadcrumbLink, BreadcrumbList, BreadcrumbPage, BreadcrumbSeparator, Bubble, BubbleContent, BubbleGroup, BubbleReactions, Button, ButtonGroup, ButtonGroupSeparator, ButtonGroupText, Calendar, CalendarBody, CalendarDays, CalendarHeader, CalendarNext, CalendarPrev, CalendarTitle, CalendarWeekdays, Card, CardAction, CardContent, CardDescription, CardFooter, CardHeader, CardTitle, Carousel, CarouselContent, CarouselItem, CarouselNext, CarouselPrevious, Chart, Checkbox, Clipboard, ClipboardPopover, ClipboardSource, ClipboardTrigger, Codeblock, Collapsible, CollapsibleContent, CollapsibleTrigger, Combobox, ComboboxBadge, ComboboxBadgeTrigger, ComboboxCheckbox, ComboboxClearButton, ComboboxEmptyState, ComboboxInputTrigger, ComboboxItem, ComboboxItemIndicator, ComboboxList, ComboboxListGroup, ComboboxPopover, ComboboxRadio, ComboboxSearchInput, ComboboxToggleAllCheckbox, ComboboxTrigger, Command, CommandDialog, CommandDialogContent, CommandDialogTrigger, CommandEmpty, CommandGroup, CommandInput, CommandItem, CommandList, CommandSeparator, CommandShortcut, Configuration, ContextMenu, ContextMenuCheckboxItem, ContextMenuContent, ContextMenuGroup, ContextMenuItem, ContextMenuLabel, ContextMenuRadioGroup, ContextMenuRadioItem, ContextMenuSeparator, ContextMenuShortcut, ContextMenuSub, ContextMenuSubContent, ContextMenuSubTrigger, ContextMenuTrigger, DataTable, DataTableBulkActions, DataTableColumnToggle, DataTableExpandToggle, DataTableForm, DataTableKaminariAdapter, DataTableManualAdapter, DataTablePagination, DataTablePaginationBar, DataTablePagyAdapter, DataTablePerPageSelect, DataTableRowCheckbox, DataTableSearch, DataTableSelectAllCheckbox, DataTableSelectionSummary, DataTableSortHead, DataTableToolbar, DatePicker, Dialog, DialogClose, DialogContent, DialogDescription, DialogFooter, DialogHeader, DialogMiddle, DialogTitle, DialogTrigger, Drawer, DrawerClose, DrawerContent, DrawerDescription, DrawerFooter, DrawerHeader, DrawerTitle, DrawerTrigger, DropdownMenu, DropdownMenuCheckboxItem, DropdownMenuContent, DropdownMenuGroup, DropdownMenuItem, DropdownMenuLabel, DropdownMenuRadioGroup, DropdownMenuRadioItem, DropdownMenuSeparator, DropdownMenuShortcut, DropdownMenuSub, DropdownMenuSubContent, DropdownMenuSubTrigger, DropdownMenuTrigger, Empty, EmptyContent, EmptyDescription, EmptyHeader, EmptyMedia, EmptyTitle, Engine, Field, FieldContent, FieldDescription, FieldError, FieldGroup, FieldLabel, FieldLegend, FieldSeparator, FieldSet, FieldTitle, Form, FormField, FormFieldError, FormFieldHint, FormFieldLabel, Heading, HoverCard, HoverCardContent, HoverCardTrigger, Icon, InlineCode, InlineLink, Input, InputGroup, InputGroupAddon, InputGroupButton, InputGroupText, InputOtp, InputOtpGroup, InputOtpSeparator, InputOtpSlot, Item, ItemActions, ItemContent, ItemDescription, ItemFooter, ItemGroup, ItemHeader, ItemMedia, ItemSeparator, ItemTitle, Kbd, KbdGroup, Label, Link, Marker, MarkerContent, MarkerIcon, MaskedInput, Menubar, MenubarCheckboxItem, MenubarContent, MenubarGroup, MenubarItem, MenubarLabel, MenubarMenu, MenubarRadioGroup, MenubarRadioItem, MenubarSeparator, MenubarShortcut, MenubarSub, MenubarSubContent, MenubarSubTrigger, MenubarTrigger, Message, MessageAvatar, MessageContent, MessageFooter, MessageGroup, MessageHeader, MessageScroller, NativeSelect, NativeSelectGroup, NativeSelectIcon, NativeSelectOption, NavigationMenu, NavigationMenuContent, NavigationMenuItem, NavigationMenuLink, NavigationMenuList, NavigationMenuTrigger, Pagination, PaginationContent, PaginationEllipsis, PaginationItem, PaginationLink, PaginationNext, PaginationPrevious, Popover, PopoverContent, PopoverDescription, PopoverHeader, PopoverTitle, PopoverTrigger, Progress, RadioButton, RadioGroup, ResizableHandle, ResizablePanel, ResizablePanelGroup, ScrollArea, Select, SelectContent, SelectGroup, SelectInput, SelectItem, SelectLabel, SelectSeparator, SelectTrigger, SelectValue, Separator, Sheet, SheetClose, SheetContent, SheetDescription, SheetFooter, SheetHeader, SheetMiddle, SheetTitle, SheetTrigger, ShortcutKey, Sidebar, SidebarContent, SidebarFooter, SidebarGroup, SidebarGroupAction, SidebarGroupContent, SidebarGroupLabel, SidebarHeader, SidebarInput, SidebarInset, SidebarMenu, SidebarMenuAction, SidebarMenuBadge, SidebarMenuButton, SidebarMenuItem, SidebarMenuSkeleton, SidebarMenuSub, SidebarMenuSubButton, SidebarMenuSubItem, SidebarRail, SidebarSeparator, SidebarTrigger, SidebarWrapper, Skeleton, Slider, Spinner, Switch, Table, TableBody, TableCaption, TableCell, TableFooter, TableHead, TableHeader, TableRow, Tabs, TabsContent, TabsList, TabsTrigger, Text, Textarea, ThemeToggle, ToastAction, ToastCancel, ToastClose, ToastDescription, ToastIcon, ToastItem, ToastRegion, ToastTitle, Toggle, ToggleGroup, ToggleGroupItem, Tooltip, TooltipContent, TooltipTrigger
Constant Summary collapse
- VERSION =
"0.7.0"
Class Method Summary collapse
- .config ⇒ Object
- .configure {|config| ... } ⇒ Object
-
.reactive? ⇒ Boolean
True when reactive helpers should be active.
Class Method Details
.config ⇒ Object
34 35 36 |
# File 'lib/phlex_kit/configuration.rb', line 34 def config @config ||= Configuration.new end |
.configure {|config| ... } ⇒ Object
38 39 40 |
# File 'lib/phlex_kit/configuration.rb', line 38 def configure yield config end |
.reactive? ⇒ Boolean
True when reactive helpers should be active. :auto follows availability.
43 44 45 46 47 48 49 50 51 |
# File 'lib/phlex_kit/configuration.rb', line 43 def reactive? case config.reactive when :auto then defined?(Phlex::Reactive) when true defined?(Phlex::Reactive) or raise "PhlexKit.config.reactive = true but phlex-reactive is not loaded — add it to your Gemfile" else false end end |